unit MainUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls;

type
  TMainForm = class(TForm)
    FreqTime: TTimer;
    OutRadios: TRadioGroup;
    HiLoPanel: TPanel;
    HiLabel: TLabel;
    LoLabel: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure OutRadiosClick(Sender: TObject);
    procedure FreqTimeTimer(Sender: TObject);
    procedure HiLabelClick(Sender: TObject);
    procedure LoLabelClick(Sender: TObject);
  protected
    CardNum: Integer;
    DeviceIndex: LongWord;
    bC3: Boolean;

    procedure GetBit;
    procedure SetBit(bHigh: Boolean);
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

uses
  AIOWDM, AIOUSB;

procedure LoadDefaultFont(IntoFont: TFont);
var
  FontSize: Integer;
  NCM: TNonClientMetrics;

begin
  NCM.cbSize := SizeOf(NCM);
  if SystemParametersInfo(SPI_GETNONCLIENTMETRICS, SizeOf(NCM), @NCM, 0) then begin
    FontSize := Round(-3/4 * NCM.lfMessageFont.lfHeight);
    IntoFont.Name := NCM.lfMessageFont.lfFaceName;
  end
  else begin
    FontSize := Abs(IntoFont.Size);
    IntoFont.Name := 'Tahoma';
  end;
  IntoFont.PixelsPerInch := 72;
  IntoFont.Size := FontSize;
end;

procedure TMainForm.FormCreate(Sender: TObject);
var
  iCard, iByte: Integer;
  iDevice: LongWord;
  DeviceID, Status, PID: LongWord;
  Outs: Word;
  DIOData: array of Byte;

begin
  LoadDefaultFont(Font);

  CardNum := -1;
  DeviceIndex := diNone;

  for iCard := 0 to GetNumCards-1 do begin
    if QueryCardInfo(iCard, @DeviceID, nil, nil, nil) = 0 then Continue;
    case DeviceID of
      $0C78: ;
      $0C61: ;
      else Continue;
    end;

    CardNum := iCard;
    Break;
  end;

  if CardNum < 0 then
    for iDevice := 0 to 31 do begin
      Status := QueryDeviceInfo(iDevice, @PID, nil, nil, nil, nil);
      if Status <> ERROR_SUCCESS then Continue;
      case PID of
        $8002: ;
        $8003: ;
        else Continue;
      end;

      DeviceIndex := iDevice;
      Break;
    end
  ;

  if CardNum >= 0 then begin
    RelOutPortB(CardNum, 3, $9A);
    RelOutPortB(CardNum, 2, $FF);
  end
  else if DeviceID <> diNone then begin
    Outs := $004;
    SetLength(DIOData, 12);
    for iByte := 0 to High(DIOData) do
      DIOData[iByte] := $FF
    ;
    DIO_Configure(DeviceIndex, False, @Outs, @DIOData[0]);
  end
  else
    Exit
  ;

  HiLoPanel.Color := $000080;
  HiLoPanel.Font.Color := $FFFFFF;
  GetBit;

  OutRadios.Enabled := True;
end;

procedure TMainForm.GetBit;
var
  Data: Byte;

begin
  if CardNum >= 0 then begin
    Data := RelInPortB(CardNum, 2);
    bC3 := (Data and $08) <> 0;
  end
  else begin
    DIO_Read1(DeviceIndex, 19, @Data);
    bC3 := Data <> 0;
  end;

  if bC3 then begin
    LoLabel.ParentColor := True;
    HiLabel.Color := $0000FF;
  end
  else begin
    HiLabel.ParentColor := True;
    LoLabel.Color := $000000;
  end;
end;

procedure TMainForm.SetBit(bHigh: Boolean);
begin
  if CardNum >= 0 then begin
    if bHigh then
      RelOutPortB(CardNum, 2, $FF)
    else
      RelOutPortB(CardNum, 2, $F7)
    ;
  end
  else begin
    DIO_Write1(DeviceIndex, 19, bHigh);
  end;
  GetBit;
end;

procedure TMainForm.OutRadiosClick(Sender: TObject);
var
  Octave: Integer;
begin
  Octave := OutRadios.ItemIndex;
  if Octave = 0 then
    FreqTime.Enabled := False
  else begin
    FreqTime.Interval := 1000 shr Octave;
    FreqTime.Enabled := True;
  end;
end;

procedure TMainForm.FreqTimeTimer(Sender: TObject);
begin
  SetBit(not bC3);
end;

procedure TMainForm.HiLabelClick(Sender: TObject);
begin
  SetBit(True);
end;

procedure TMainForm.LoLabelClick(Sender: TObject);
begin
  SetBit(False);
end;

end.
